==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/pl/servicediscovery.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>DiscoInfoWindow</name>
    <message>
        <source>Error %1: %2</source>
        <translation>Błąd %1: %2</translation>
    </message>
    <message>
        <source>Discovery Info - %1</source>
        <translation>Wykryte informacje - %1</translation>
    </message>
</context>
<context>
    <name>DiscoInfoWindowClass</name>
    <message>
        <source>Identities:</source>
        <translation>Elementy:</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Features:</source>
        <translation>Funkcje:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Opis:</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uaktualnienie</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Rozszerzenia</translation>
    </message>
</context>
<context>
    <name>DiscoItemsModel</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Węzeł</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Identity:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Element:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;%1 (Category: &apos;%2&apos;; Type: &apos;%3&apos;)&lt;/li&gt;</source>
        <translation>&lt;li&gt;%1 (Kategoria: &apos;%2&apos;; Typ: &apos;%3&apos;)&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Features:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Funkcje:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Error %1: %2</source>
        <translation>Błąd %1: %2</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindow</name>
    <message>
        <source>Back</source>
        <translation>Z powrotem</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Do przodu</translation>
    </message>
    <message>
        <source>Discover</source>
        <translation>Wykryj</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Service Discovery - %1</source>
        <translation>Wykryte serwisy - %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindowClass</name>
    <message>
        <source>Node:</source>
        <translation>Węzeł:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Akcje</translation>
    </message>
    <message>
        <source>Item:</source>
        <translation>Element:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Szukaj:</translation>
    </message>
</context>
<context>
    <name>ServiceDiscovery</name>
    <message>
        <source>Service Discovery</source>
        <translation>Wykrywanie serwisów</translation>
    </message>
    <message>
        <source>JID Escaping</source>
        <translation>Obsługa znaków zabronionych w JID</translation>
    </message>
    <message>
        <source>Discovery Info</source>
        <translation>Wykryte informacje</translation>
    </message>
    <message>
        <source>Entity Capabilities</source>
        <translation>Cechy obiektu</translation>
    </message>
    <message>
        <source>Allows to receive information about Jabber entities</source>
        <translation>Pozwala na otrzymywanie informacji na temat elementów Jabbera</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information and items</source>
        <translation>Umożliwia wymianę informacji i przegląd elementów</translation>
    </message>
    <message>
        <source>Discovery Information</source>
        <translation>Wykryte informacje</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information</source>
        <translation>Umożliwia wymianę wykrytych informacji</translation>
    </message>
    <message>
        <source>Discovery Items</source>
        <translation>Wykryte elementy</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery items</source>
        <translation>Umożliwia wymianę wykrytych elementów</translation>
    </message>
    <message>
        <source>Publish Items</source>
        <translation>Publikacja elementów</translation>
    </message>
    <message>
        <source>Supports the publishing of the discovery items</source>
        <translation>Obsługa publikacji wykrytych elementów</translation>
    </message>
    <message>
        <source>Supports the caching of the discovery information</source>
        <translation>Obsługa buforowania wykrytych informacji</translation>
    </message>
    <message>
        <source>Supports the displaying of the jabber identifiers with disallowed characters</source>
        <translation>Umożliwia wyświetlanie znaków zabronionych w identyfikatorach Jabber</translation>
    </message>
    <message>
        <source>Service discovery window</source>
        <translation>Okno właściwości serwisu</translation>
    </message>
    <message>
        <source>Move back</source>
        <translation>Do tyłu</translation>
    </message>
    <message>
        <source>Move forward</source>
        <translation>Do przodu</translation>
    </message>
    <message>
        <source>Discover item</source>
        <translation>Właściwości elementu</translation>
    </message>
    <message>
        <source>Reload items</source>
        <translation>Odśwież elementy</translation>
    </message>
    <message>
        <source>Show discovery info</source>
        <translation>Pokaż odkryte informacje</translation>
    </message>
    <message>
        <source>Add item to roster</source>
        <translation>Dodaj element do listy kontaktów</translation>
    </message>
    <message>
        <source>Show vCard</source>
        <translation>Pokaż wizytówkę vCard</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <comment>Show vCard</comment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Close discovery window</source>
        <translation>Zamknij odkryte informacje</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close discovery window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Category: %1; Type: %2</source>
        <translation>Kategoria: %1; Typ: %2</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/pl/servicediscovery.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>DiscoInfoWindow</name>
    <message>
        <source>Discovery Info - %1</source>
        <translation>Wykryte informacje - %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
</context>
<context>
    <name>DiscoInfoWindowClass</name>
    <message>
        <source>Identities:</source>
        <translation>Elementy:</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Features:</source>
        <translation>Funkcje:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Opis:</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uaktualnienie</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Rozszerzenia</translation>
    </message>
</context>
<context>
    <name>DiscoItemsModel</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Węzeł</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Identity:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Element:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;%1 (Category: &apos;%2&apos;; Type: &apos;%3&apos;)&lt;/li&gt;</source>
        <translation>&lt;li&gt;%1 (Kategoria: &apos;%2&apos;; Typ: &apos;%3&apos;)&lt;/li&gt;</translation>
    </message>
    <message>
        <source>&lt;li&gt;&lt;b&gt;Features:&lt;/b&gt;&lt;/li&gt;</source>
        <translation>&lt;li&gt;&lt;b&gt;Funkcje:&lt;/b&gt;&lt;/li&gt;</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindow</name>
    <message>
        <source>Back</source>
        <translation>Z powrotem</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Do przodu</translation>
    </message>
    <message>
        <source>Discover</source>
        <translation>Wykryj</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Service Discovery - %1</source>
        <translation>Wykryte serwisy - %1</translation>
    </message>
</context>
<context>
    <name>DiscoItemsWindowClass</name>
    <message>
        <source>Node:</source>
        <translation>Węzeł:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Akcje</translation>
    </message>
    <message>
        <source>Item:</source>
        <translation>Element:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Szukaj:</translation>
    </message>
</context>
<context>
    <name>ServiceDiscovery</name>
    <message>
        <source>Service Discovery</source>
        <translation>Wykrywanie serwisów</translation>
    </message>
    <message>
        <source>JID Escaping</source>
        <translation>Obsługa znaków zabronionych w JID</translation>
    </message>
    <message>
        <source>Discovery Info</source>
        <translation>Wykryte informacje</translation>
    </message>
    <message>
        <source>Entity Capabilities</source>
        <translation>Cechy obiektu</translation>
    </message>
    <message>
        <source>Allows to receive information about Jabber entities</source>
        <translation>Pozwala na otrzymywanie informacji na temat elementów Jabbera</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information and items</source>
        <translation>Umożliwia wymianę informacji i przegląd elementów</translation>
    </message>
    <message>
        <source>Discovery Information</source>
        <translation>Wykryte informacje</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery information</source>
        <translation>Umożliwia wymianę wykrytych informacji</translation>
    </message>
    <message>
        <source>Discovery Items</source>
        <translation>Wykryte elementy</translation>
    </message>
    <message>
        <source>Supports the exchange of the discovery items</source>
        <translation>Umożliwia wymianę wykrytych elementów</translation>
    </message>
    <message>
        <source>Publish Items</source>
        <translation>Publikacja elementów</translation>
    </message>
    <message>
        <source>Supports the publishing of the discovery items</source>
        <translation>Obsługa publikacji wykrytych elementów</translation>
    </message>
    <message>
        <source>Supports the caching of the discovery information</source>
        <translation>Obsługa buforowania wykrytych informacji</translation>
    </message>
    <message>
        <source>Supports the displaying of the jabber identifiers with disallowed characters</source>
        <translation>Umożliwia wyświetlanie znaków zabronionych w identyfikatorach Jabber</translation>
    </message>
    <message>
        <source>Service discovery window</source>
        <translation>Okno właściwości serwisu</translation>
    </message>
    <message>
        <source>Move back</source>
        <translation>Do tyłu</translation>
    </message>
    <message>
        <source>Move forward</source>
        <translation>Do przodu</translation>
    </message>
    <message>
        <source>Discover item</source>
        <translation>Właściwości elementu</translation>
    </message>
    <message>
        <source>Reload items</source>
        <translation>Odśwież elementy</translation>
    </message>
    <message>
        <source>Show discovery info</source>
        <translation>Pokaż odkryte informacje</translation>
    </message>
    <message>
        <source>Add item to roster</source>
        <translation>Dodaj element do listy kontaktów</translation>
    </message>
    <message>
        <source>Show vCard</source>
        <translation>Pokaż wizytówkę vCard</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <comment>Show vCard</comment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Close discovery window</source>
        <translation>Zamknij odkryte informacje</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close discovery window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Category: %1; Type: %2</source>
        <translation>Kategoria: %1; Typ: %2</translation>
    </message>
</context>
</TS>
